:py:mod:`~manen.page_object_model.config`
=========================================

.. automodule:: manen.page_object_model.config
   :members:
   :undoc-members:
   :show-inheritance:
   :ignore-module-all:
